%%
%% This is file `sjtu-text-font-libertinus.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,text,libertinus')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Libertinus text fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-text-font-libertinus.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \setmainfont
      { LibertinusSerif }
      [
        Extension           = .otf,
        UprightFont         = *-Regular,
        BoldFont            = *-Bold,
        ItalicFont          = *-Italic,
        BoldItalicFont      = *-BoldItalic,
        SlantedFont         = *-Regular,
        BoldSlantedFont     = *-Bold,
        SlantedFeatures     = { FakeSlant = 0.2 },
        BoldSlantedFeatures = { FakeSlant = 0.2 }
      ]
    \setsansfont
      { LibertinusSans }
      [
        Extension           = .otf,
        UprightFont         = *-Regular,
        BoldFont            = *-Bold,
        ItalicFont          = *-Italic,
        BoldItalicFont      = *-Italic,
        BoldItalicFeatures  = { FakeBold  = 3   },
        SlantedFont         = *-Regular,
        BoldSlantedFont     = *-Bold,
        SlantedFeatures     = { FakeSlant = 0.2 },
        BoldSlantedFeatures = { FakeSlant = 0.2 }
      ]
  }
  {
    \tl_set:Nn \encodingdefault { T1 }
    \tl_set:Nn \rmdefault { LibertinusSerif-TLF }
    \tl_set:Nn \sfdefault { LibertinusSans-TLF  }
    \tl_set:Nn \ttdefault { lmtt }
  }
\endinput
%%
%% End of file `sjtu-text-font-libertinus.def'.
