%%
%% This is file `sjtu-lang-en.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `lang,en')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {English specific definition (SJTUTeX)}
\ProvidesExplFile{sjtu-lang-en.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\NewHook { sjtutex / lang / en }
\keys_define:nn { sjtu / private }
  {
    lang / en .code:n =
      {
        \tl_set_eq:NN \l__sjtu_lang_tl \l_keys_value_tl
        \normalfont
        \UseHook { sjtutex / lang / en }
      } ,
    en .meta:n = { lang = en } ,
    en .groups:n = { lang }
  }
\AddToHook { sjtutex / lang / en }
  {
    \tl_set:Nn \languagename { english }
    \ctex_set:n { autoindent = 1.5 em }
  }
\cs_set_eq:NN \__sjtu_title_case_aux_en:n \MakeUppercase
\clist_const:Nn \c__sjtu_name_month_en_clist
  {
    January, February, March, April, May, June,
    July, August, September, October, November, December
  }
\cs_new:Npn \__sjtu_ordinal_en:n #1
  {
    \int_to_arabic:n {#1}
    \exp_not:N \textsuperscript
      {
        \int_case:nnF { \int_mod:nn {#1} { 100 } }
          {
            { 11 } { th }
            { 12 } { th }
            { 13 } { th }
          }
          {
            \int_case:nnF { \int_mod:nn {#1} { 10 } }
              {
                { 1 } { st }
                { 2 } { nd }
                { 3 } { rd }
              }
              { th }
          }
      }
  }
\cs_new:Npn \__sjtu_date_aux_en:nnn #1#2#3
  {
    \clist_item:Nn \c__sjtu_name_month_en_clist {#2} ~
    \__sjtu_ordinal_en:n {#3} ,~
    \int_to_arabic:n {#1}
  }
\cs_new:Npn \__sjtu_date_aux_en:w #1-#2-#3 \q_stop
  { \__sjtu_date_aux_en:nnn {#1} {#2} {#3} }
\cs_new:Npn \__sjtu_date_aux_short_en:nn #1#2
  {
    \clist_item:Nn \c__sjtu_name_month_en_clist {#2} ,~
    \int_to_arabic:n {#1}
  }
\cs_new:Npn \__sjtu_date_aux_short_en:w #1-#2 \q_stop
  { \__sjtu_date_aux_short_en:nn {#1} {#2} }
\clist_map_inline:nn
  {
    { keywords } { Key~words       } ,
    { info_sep } { \hbox { :~ }    } ,
    { item_sep } { ,~              }
  }
  { \__sjtu_name_const:nnn { en } #1 }
\IfClassLoadedF { sjtuthesis } { \endinput }
\__sjtu_name_const_from_clist:nnnn { en }
  { degree_level } { \g__sjtu_thesis_type_int }
  { Bachelor, Master, Doctor }
\clist_map_inline:nn
  {
    { univ             } { Shanghai~ Jiao~ Tong~ University } ,
    { address          } { Shanghai,~ P.R.~ China           } ,
    { title_page       } { Title~ Page                      } ,
    { declaration      } { Statutory~ Declaration           } ,
    { abstract         } { Abstract                         }
  }
  { \__sjtu_name_const:nnn { en } #1 }
\tl_const:Nn \c__sjtu_name_subject_en_tl
  {
    A~ Dissertation~ Submitted~ to \\
    { \c__sjtu_name_univ_en_tl }~ for~
    the~ Degree~ of~ { \c__sjtu_name_degree_level_en_tl }
  }
\endinput
%%
%% End of file `sjtu-lang-en.def'.
