%%
%% This is file `sjtu-math-font-lm.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,math,type1,lm')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Latin Modern math fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-math-font-lm.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\RequirePackage { amssymb, upgreek }
\SetSymbolFont { operators    } { normal } { OT1 } { lmr  } { m  } { n  }
\SetSymbolFont { letters      } { normal } { OML } { lmm  } { m  } { it }
\SetSymbolFont { symbols      } { normal } { OMS } { lmsy } { m  } { n  }
\SetSymbolFont { largesymbols } { normal } { OMX } { lmex } { m  } { n  }
\SetSymbolFont { operators    } { bold   } { OT1 } { lmr  } { bx } { n  }
\SetSymbolFont { letters      } { bold   } { OML } { lmm  } { b  } { it }
\SetSymbolFont { symbols      } { bold   } { OMS } { lmsy } { b  } { n  }
\SetSymbolFont { largesymbols } { bold   } { OMX } { lmex } { m  } { n  }
\SetMathAlphabet { \mathbf } { normal } { OT1 } { lmr  } { bx } { n  }
\SetMathAlphabet { \mathsf } { normal } { OT1 } { lmss } { m  } { n  }
\SetMathAlphabet { \mathit } { normal } { OT1 } { lmr  } { m  } { it }
\SetMathAlphabet { \mathtt } { normal } { OT1 } { lmtt } { m  } { n  }
\SetMathAlphabet { \mathbf } { bold   } { OT1 } { lmr  } { bx } { n  }
\SetMathAlphabet { \mathsf } { bold   } { OT1 } { lmss } { bx } { n  }
\SetMathAlphabet { \mathit } { bold   } { OT1 } { lmr  } { bx } { it }
\SetMathAlphabet { \mathtt } { bold   } { OT1 } { lmtt } { m  } { n  }
\__sjtu_set_slanted_greek:
\bool_if:NT \g__sjtu_upright_integral_bool
  { \RequirePackage { cmupint } }
\__sjtu_set_unimath_symbol:
\endinput
%%
%% End of file `sjtu-math-font-lm.def'.
