%%
%% This is file `sjtu-scheme-en.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `scheme,en')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {English scheme (SJTUTeX)}
\ProvidesExplFile{sjtu-scheme-en.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\ctex_if_autoindent_touched:F
  { \ctex_set:n { autoindent = 1.5 em } }
\ctex_patch_cmd:Nnn \quotation { 1.5em } { \parindent }
\keys_set:nn { sjtu / style }
  { fnmark-style = plain   }
\tl_set:Nn \languagename { english  }
\clist_map_inline:nn
  {
    { assumption  } { Assumption  } ,
    { axiom       } { Axiom       } ,
    { conjecture  } { Conjecture  } ,
    { corollary   } { Corollary   } ,
    { definition  } { Definition  } ,
    { example     } { Example     } ,
    { exercise    } { Exercise    } ,
    { lemma       } { Lemma       } ,
    { problem     } { Problem     } ,
    { proposition } { Proposition } ,
    { remark      } { Remark      } ,
    { solution    } { Solution    } ,
    { theorem     } { Theorem     }
  }
  { \__sjtu_name_const:nnn { en } #1 }
\endinput
%%
%% End of file `sjtu-scheme-en.def'.
