%%
%% This is file `sjtu-scheme-ja.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `scheme,ja')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Japanese scheme (SJTUTeX)}
\ProvidesExplFile{sjtu-scheme-ja.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\keys_set_known:nn { ctex / chapter }
  { name = { 第 \space , \space 章 } }
\ctex_if_autoindent_touched:F
  { \ctex_set:n { autoindent = 1 } }
\ctex_patch_cmd:Nnn \verse { -1.5em } { -2 \ccwd }
\ctex_patch_cmd:Nnn \verse {  1.5em } {  2 \ccwd }
\ctex_patch_cmd:Nnn \quotation { 1.5em } { \parindent }
\keys_set:nn { sjtu / style }
  { fnmark-style = circled }
\tl_set:Nn \languagename { japanese }
\keys_set_known:nn { sjtu / name }
  {
    contents      = { 目 \protect \quad 次 } ,
    listfigure    = { 図目次               } ,
    listtable     = { 表目次               } ,
    figure        = { 図                   } ,
    table         = { 表                   } ,
    abstract      = { 概 \protect \quad 要 } ,
    index         = { 索 \protect \quad 引 } ,
    appendix      = { 付録                 } ,
    proof         = { 证明                 } ,
    bib           = { 参考文献             } ,
    figure*       = { Figure               } ,
    table*        = { Table                } ,
    algorithm     = { アルゴリズム         } ,
    listalgorithm = { アルゴリズム目次     } ,
    abbr          = { 略語表               } ,
    nom           = { 記号表               } ,
    ack           = { 謝 \protect \quad 辞 } ,
    resume        = { 履歴書               } ,
    digest        = { 要 \protect \quad 約 } ,
    achv          = { 研究業績書           }
  }
\clist_map_inline:nn
  {
    { assumption  } { 仮定        } ,
    { axiom       } { 公理        } ,
    { conjecture  } { 予想        } ,
    { corollary   } { 系          } ,
    { definition  } { 定義        } ,
    { example     } { 例          } ,
    { exercise    } { 練習        } ,
    { lemma       } { 補題        } ,
    { problem     } { 問題        } ,
    { proposition } { 命題        } ,
    { remark      } { 注意        } ,
    { solution    } { 解法        } ,
    { theorem     } { 定理        }
  }
  { \__sjtu_name_const:nnn { ja } #1 }
\endinput
%%
%% End of file `sjtu-scheme-ja.def'.
