%%
%% This is file `sjtu-text-font-cambria.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,text,otf,cambria')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Cambria text fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-text-font-cambria.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \setmainfont { Cambria }
    \setsansfont { Calibri }
    \setmonofont { Consolas } [ Scale = 0.95 ]
  }
  { \__sjtu_fontset_error:nn { text } { cambria } }
\endinput
%%
%% End of file `sjtu-text-font-cambria.def'.
