%%
%% This is file `sjtu-cjk-font-windows.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,cjk,windows')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Windows CJK fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-cjk-font-windows.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \__sjtu_if_main_lang_ja:TF
      {
        \setCJKmainfont { MS~Mincho } [ AutoFakeBold = 3 ]
        \setCJKsansfont { MS~Gothic } [ AutoFakeBold = 3 ]
        \setCJKmonofont { MS~Mincho }
        \setCJKfamilyfont { jamin  } { MS~Mincho } [ AutoFakeBold = 3 ]
        \setCJKfamilyfont { jagoth } { MS~Gothic } [ AutoFakeBold = 3 ]
        \NewDocumentCommand \mincho   { } { \CJKfamily { jamin   } }
        \NewDocumentCommand \gothic   { } { \CJKfamily { jagoth  } }
      }
      {
        \setCJKmainfont { SimSun   }
          [ AutoFakeBold = 3 , ItalicFont = KaiTi ]
        \setCJKsansfont { SimHei   } [ AutoFakeBold = 3 ]
        \setCJKmonofont { FangSong }
      }
    \setCJKfamilyfont { zhsong } { SimSun   }
      [ AutoFakeBold = 3 , ItalicFont = KaiTi ]
    \setCJKfamilyfont { zhhei  } { SimHei   } [ AutoFakeBold = 3 ]
    \setCJKfamilyfont { zhkai  } { KaiTi    }
    \setCJKfamilyfont { zhfs   } { FangSong }
    \NewDocumentCommand \songti   { } { \CJKfamily { zhsong  } }
    \NewDocumentCommand \heiti    { } { \CJKfamily { zhhei   } }
    \NewDocumentCommand \fangsong { } { \CJKfamily { zhfs    } }
    \NewDocumentCommand \kaishu   { } { \CJKfamily { zhkai   } }
  }
  {
    \__sjtu_if_main_lang_ja:TF
      { \__sjtu_fontset_error:nn { cjk } { windows } }
      { \ctex_file_input:n { ctex-fontset-windows.def } }
  }
\endinput
%%
%% End of file `sjtu-cjk-font-windows.def'.
