%%
%% This is file `ctex-scheme-chinese.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% ctex.dtx  (with options: `scheme,generic,chinese')
%% 
%%     Copyright (C) 2003--2022
%%     CTEX.ORG and any individual authors listed in the documentation.
%% ---------------------------------------------------------------------
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. This version of this license is in
%%        http://www.latex-project.org/lppl/lppl-1-3c.txt
%%     and the latest version of this license is in
%%        http://www.latex-project.org/lppl.txt
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
%%     This work has the LPPL maintenance status "maintained".
%% 
%% ---------------------------------------------------------------------
%% 
\GetIdInfo$Id: ctex.dtx 13a2256 2022-07-14 18:54:09 +0800 Qing Lee <sobenlee@gmail.com> $
  {Chinese scheme for generic (CTEX)}
\ProvidesExplFile{ctex-scheme-chinese.def}
  {\ExplFileDate}{2.5.10}{\ExplFileDescription}
\ctex_set:n { today = small }
\ctex_if_autoindent_touched:F
  { \ctex_set:n { autoindent = true } }
\tl_if_eq:NnTF \c__ctex_std_class_tl { beamer }
  {
    \str_if_eq:onTF { \g__ctex_encoding_tl } { GBK }
      {
        \uselanguage { ChineseGBK }
        \languagealias { chinese } { ChineseGBK }
        \ctex_file_input:n { ctex-name-gbk.cfg }
      }
      {
        \uselanguage { ChineseUTF8 }
        \languagealias { chinese } { ChineseUTF8 }
        \ctex_file_input:n { ctex-name-utf8.cfg }
      }
    \clist_put_left:Nn \trans@languagepath { chinese }
  }
  {
    \str_if_eq:onTF { \g__ctex_encoding_tl } { GBK }
      { \ctex_file_input:n { ctex-name-gbk.cfg } }
      { \ctex_file_input:n { ctex-name-utf8.cfg } }
    \int_compare:nNnF \g__ctex_font_size_int > { -1 }
      { \int_gset:Nn \g__ctex_font_size_int { 0 } }
    \fp_if_nan:nT { \l__ctex_line_spread_fp }
      { \fp_set:Nn \l__ctex_line_spread_fp { 1.3 } }
    \tl_if_exist:NT \c__ctex_std_class_tl
      { \RequirePackage { indentfirst } }
  }
%% 
%%
%% End of file `ctex-scheme-chinese.def'.
