%%
%% This is file `sjtu-math-font-times.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,math,type1,times')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Times math fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-math-font-times.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\PassOptionsToPackage { Symbol } { upgreek }
\RequirePackage { amssymb, upgreek }
\tl_set_eq:NN \l__sjtu_save_rmdefault_tl \rmdefault
  \RequirePackage { mathptmx }
\tl_set_eq:NN \rmdefault \l__sjtu_save_rmdefault_tl
\tl_set:Nn \Hv@scale { 0.94 }
\DeclareMathAlphabet { \mathsf } { OT1 } { phv } { m } { n }
\DeclareMathAlphabet { \mathtt } { OT1 } { pcr } { m } { n }
\SetMathAlphabet { \mathsf } { bold } { OT1 } { phv } { b } { n }
\SetMathAlphabet { \mathtt } { bold } { OT1 } { pcr } { b } { n }
\DeclareSymbolFont { SJTU@ptm } { OML } { ptmcm } { m } { it }
\__sjtu_declare_math_symbol:nnNn { \mathord } { SJTU@ptm } \upvarsigma { "26 }
\bool_if:NT \g__sjtu_upright_integral_bool
  { \RequirePackage { cmupint } }
\__sjtu_set_unimath_symbol:
\endinput
%%
%% End of file `sjtu-math-font-times.def'.
